@@ -1,11 +1,11 @@
 package TestApp::Controller::Root;
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 use Moose;
+use namespace::autoclean;
 
 BEGIN { extends 'Catalyst::Controller' }
 
-__PACKAGE__->config(namespace => q{});
-
+__PACKAGE__->config( namespace => '' );
 
 sub main :Path {
     my ($self, $c) = @_;
